@@ -5,7 +5,7 @@ import argparse
 global distro 
 distro = ["apt","yay", "paru", "pacman", "dnf"]
 global found
-found = subprocess.getoutput("./getPackageManager.sh") # you need your path setup to .local/bin in shell to run this script to get the distro pakacge manager
+found = subprocess.getoutput(".././getPackageManager.sh") # you need your path setup to .local/bin in shell to run this script to get the distro pakacge manager
 #print (found)
 
 def installPkgs():
